@@ -1,3 +1,4 @@
+import datetime
 from typing import Any, Optional
 
 from mixins import ReprMixin
@@ -7,7 +8,8 @@ class AnalysisResult(ReprMixin):
     repr_cols = ['name', 'location', 'result']
 
     def __init__(self, result: Any = None, name: Optional[str] = None,
-                 location: Optional[str] = None):
+                 location: Optional[str] = None, last_modified: Optional[datetime.datetime] = None):
         self.result = result
         self.name = name
         self.location = location
+        self.last_modified = last_modified
