@@ -1,10 +1,13 @@
 from typing import Optional, Union
 
+from mixins import ReprMixin
+
 from datacode.models.dtypes.base import DataType
 from datacode.models.dtypes.convert import convert_str_to_data_type_if_necessary
 
 
-class Index:
+class Index(ReprMixin):
+    repr_cols = ['key', 'dtype']
 
     def __init__(self, key: str, dtype: Optional[Union[str, DataType]] = None):
         dtype = convert_str_to_data_type_if_necessary(dtype)
