@@ -1,8 +1,7 @@
 import uuid
 from copy import deepcopy
 from functools import partial
-from typing import TYPE_CHECKING, Callable, Optional, Sequence
-
+from typing import TYPE_CHECKING, Callable, Optional, Sequence, Union
 
 if TYPE_CHECKING:
     from datacode.models.source import DataSource
@@ -21,7 +20,22 @@ class SourceTransform(Transform):
     repr_cols = ['key', 'name_func', 'data_func', 'symbol_func', 'subset']
 
     def __init__(self, key: str, name_func: StrFunc = None, data_func: ValueFunc = None,
-                 symbol_func: SymbolFunc = None, subset: Sequence['Variable'] = None):
+                 symbol_func: SymbolFunc = None,
+                 subset: Optional[Union[
+                     Sequence['Variable'],
+                     Callable[['DataSource'], Sequence['Variable']]
+                 ]] = None):
+        """
+
+        :param key: Unique string used to identify the transform
+        :param name_func: Function which modifies names of variables
+        :param data_func: Function which modifies data
+        :param symbol_func: Function which modifies symbols of variables
+        :param subset: A sequence of variables or a function which accepts a data source
+            and returns a sequence of variables from it. While data_func will still be
+            called on the entire data, name and symbol transforms as well as transform
+            keys will only be added to the subset variables
+        """
         super().__init__(
             key,
             name_func=name_func,
@@ -54,7 +68,9 @@ class SourceTransform(Transform):
         if self.data_func is not None:
             source = self.data_func(source)
 
-        if self.subset is None:
+        if callable(self.subset):
+            subset = self.subset(source)
+        elif self.subset is None:
             subset = source.load_variables
         else:
             subset = deepcopy(self.subset)
@@ -88,7 +104,10 @@ class SourceTransform(Transform):
 
     @classmethod
     def from_func(cls, func: Callable[['DataSource'], 'DataSource'] = None, key: Optional[str] = None,
-                  subset: Sequence['Variable'] = None):
+                  subset: Optional[Union[
+                      Sequence['Variable'],
+                      Callable[['DataSource'], Sequence['Variable']]
+                  ]] = None):
         if key is None:
             key = str(uuid.uuid4())
         return cls(
@@ -98,14 +117,22 @@ class SourceTransform(Transform):
         )
 
     @classmethod
-    def from_transform(cls, transform: Transform, subset: Sequence['Variable'] = None):
+    def from_transform(cls, transform: Transform,
+                       subset: Optional[Union[
+                           Sequence['Variable'],
+                           Callable[['DataSource'], Sequence['Variable']]
+                       ]] = None):
         # Transform is by variable, need to create new data function which
         # accepts source and applies to subset of variables one by one
         def data_func(subset: Optional[Sequence[str]], source: 'DataSource', **kwargs) -> 'DataSource':
-            if subset is None:
-                subset = source.load_variables
+            if callable(subset):
+                use_subset = subset(source)
+            elif subset is None:
+                use_subset = source.load_variables
+            else:
+                use_subset = subset
 
-            for variable in subset:
+            for variable in use_subset:
                 col = source.col_for(variable=variable)
                 source = transform.data_func(col, variable, source, **kwargs)
 
